@@ -332,163 +332,6 @@ def remove_combine(pathfileout, filememory):
     conn_pathfileout.commit()
     conn_pathfileout.execute(""" DETACH DATABASE this_avg_db """)
 
-def remove_create_and_populate_moyenne_table(family, 
-                                      new_db_filename,
-                                      existing_db_filename,
-                                      region_seleccionada,
-                                      selected_flags, 
-                                      FONCTION,
-                                      boxsizex,
-                                      boxsizey,
-                                      varnos,
-                                      channel,
-                                      id_stn,
-                                      interval):
-    import sqlite3
-    import re
-    import pikobs  
-    pattern = r'(\d{10})'
-    match = re.search(pattern, existing_db_filename)
-    if match:
-        date = match.group(1)
-    else:
-        raise ValueError("No se encontraron 10 dígitos consecutivos en el nombre del archivo.")
-    filename=f"file::memory:?cache=shared"
-
-    new_db_conn = sqlite3.connect(filename, uri=True, isolation_level=None, timeout=9999999)
-    new_db_cursor = new_db_conn.cursor()
-
-    FAM, VCOORD, VCOCRIT, STATB, element, VCOTYP = pikobs.family(family)
-    if varnos:
-        element = ",".join(varnos)
-
-    if channel == 'join' and id_stn == 'all':
-        group_channel = '"join" as Chan,'
-        group_id_stn = 'id_stn as id_stn,'
-        group_id_stn_vcoord = 'group by 2, 3, 4, 5, id_stn'
-    elif channel == 'all' and id_stn == 'join':
-        group_channel = f'{VCOORD} as Chan,'
-        group_id_stn = '"join" as id_stn,'
-        group_id_stn_vcoord = f'group by 2, 3, 4, 5, {VCOORD}'
-    elif channel == 'all' and id_stn == 'all':
-        group_channel = f'{VCOORD} as Chan,'
-        group_id_stn = 'id_stn as id_stn,'
-        group_id_stn_vcoord = f'group by 2, 3, 4, 5, id_stn, {VCOORD}'
-    elif channel == 'join' and id_stn == 'join':
-        group_channel = '"join" as Chan,'
-        group_id_stn = '"join" as id_stn,'
-        group_id_stn_vcoord = 'group by 2, 3, 4, 5, date'
-
-    LAT1, LAT2, LON1, LON2 = pikobs.regions(region_seleccionada)
-    LATLONCRIT = pikobs.generate_latlon_criteria(LAT1, LAT2, LON1, LON2)
-    flag_criteria = pikobs.flag_criteria(selected_flags)
-    STNID = f"floor(360. / {boxsizex}) * floor(lat / {boxsizey}) + floor(MIN(179.99, lon) / {boxsizex})"
-    LAT = f"floor(lat / {boxsizey}) * {boxsizey} + {boxsizey} / 2."
-    LON = f"floor(MIN(179.99, lon) / {boxsizex}) * {boxsizex} + {boxsizex} / 2."
-
-    new_db_cursor.execute("PRAGMA journal_mode = OFF;")
-    new_db_cursor.execute("PRAGMA journal_mode = MEMORY;")
-    new_db_cursor.execute("PRAGMA synchronous = OFF;")
-    new_db_cursor.execute("PRAGMA foreign_keys = OFF;")
-    new_db_cursor.execute(f"ATTACH DATABASE '{existing_db_filename}' AS db;")
-    # Check if 'bias_corr' exists in the table schema
-    bias_corr_exists = False
-    new_db_cursor.execute("PRAGMA table_info('DATA')")
-    columns = new_db_cursor.fetchall()
-    interval_a=interval[0]
-    interval_b=interval[1]
-
-    if  interval_a==None and  interval_b==None:
-          criteria_interval = ''
-          layers='layer_all'
-    else:
-          criteria_interval = f'and vcoord >= {interval_a*100} AND vcoord <= {interval_b*100}'
-          layers=f'layerfrom{interval_a}MPato{interval_b}MPa'
-
-
-    for col in columns:
-      if col[1] == 'bias_corr':  # Column name is at index 1
-        bias_corr_exists = True
-        break
-
-    # Adjust the query based on the existence of 'bias_corr'
-    bias_corr_sum = "sum(bias_corr)" if bias_corr_exists else "NULL"
-    bias_corr_sq_sum = "sum(bias_corr * bias_corr)" if bias_corr_exists else "NULL"
-
-    new_db_cursor.execute("""
-        CREATE TABLE IF NOT EXISTS moyenne (
-            Nrej INTEGER,
-            Nacc INTEGER,
-            Nprofile INTEGER,
-            DATE INTEGER,
-            lat FLOAT,
-            lon FLOAT,
-            boite INTEGER,
-            id_stn TEXT,
-            varno INTEGER,
-            vcoord FLOAT,   -- INTEGER FLOAT canal
-            sumx FLOAT,
-            sumy FLOAT,
-            sumz FLOAT,
-            sumStat FLOAT,
-            sumx2 FLOAT,
-            sumy2 FLOAT,
-            sumz2 FLOAT,
-            sumStat2 FLOAT,
-            n INTEGER,
-            flag INTEGER
-        ); """)
-    qr = f"""
-    INSERT INTO moyenne (
-        DATE, lat, lon, boite, varno, vcoord, 
-        sumx, sumy, sumz, sumStat, 
-        sumx2, sumy2, sumz2, sumStat2, 
-        n, Nrej, Nacc, Nprofile, id_stn, flag
-    )
-    SELECT
-        {date},
-        {LAT},
-        {LON},
-        {STNID},
-        VARNO,
-        {group_channel}
-        sum(omp),
-        sum(oma),
-        sum(obsvalue), 
-        {bias_corr_sum}, -- sum(bias_corr)
-        sum(omp * omp),
-        sum(oma * oma),
-        sum(obsvalue * obsvalue),
-        {bias_corr_sq_sum}, -- sum(bias_corr * bias_corr)
-        COUNT(*),
-        sum(flag & 512=512),
-        sum(flag & 4096-4094),
-        count(distinct id_obs),
-        {group_id_stn}
-        flag
-    FROM
-        db.header
-    NATURAL JOIN
-        db.DATA
-    WHERE
-        varno IN ({element}) 
-        AND obsvalue IS NOT NULL
-        {flag_criteria}
-        {LATLONCRIT}
-        {VCOCRIT}
-        {criteria_interval}
-    {group_id_stn_vcoord};
-    """
-    new_db_cursor.execute(qr)
-
-    # Finalizar
-    new_db_conn.commit()
-    #new_db_conn.close()
-    try:
-         combine(new_db_filename, filename)
-    except sqlite3.Error as error:
-         print(f"Error while creating a single sqlite file:  {os.path.basename(filename)}", error)
-
 def create_and_populate_moyenne_table(
     family,
     new_db_filename: str,
@@ -580,7 +423,7 @@ def create_and_populate_moyenne_table(
         # Check for existence of bias_corr column
         cursor.execute("PRAGMA table_info('DATA')")
         columns = [col[1] for col in cursor.fetchall()]
-        has_bias_corr = 'bias_corr' in columns
+        has_bias_corr = 'BIAS_CORR' in columns
 
         # Interval criteria
         interval_a, interval_b = interval
@@ -662,7 +505,6 @@ def create_and_populate_moyenne_table(
             {interval_criteria}
         {group_by};
         """
-
         cursor.execute(insert_query)
         mem_conn.commit()
 
@@ -1139,11 +981,13 @@ def make_scatter(files_in,
                                                  data_['interval'])for data_ in data_list]
               # print ('close0')
                results = dask.compute(*delayed_funcs)
-               print ('close1')
+               
                client.close()
 
         tn= time.time()
         print ('Total time for statistics:',tn-t0 )  
+        time.sleep(5)
+
         data_list_plot = create_data_list_plot(datestart,
                                              dateend, 
                                              families, 
@@ -1161,7 +1005,6 @@ def make_scatter(files_in,
                                             )
 
         t0 = time.time()
-        #n_cpu=1
         if n_cpu==1:  
          print (f'in Serie plots = {len(data_list_plot)}')
          for  data_ in data_list_plot:  
